# `drf-versioned-models`

Versioned models for Django REST Framework.

## Installation

```shell
pip install drf-versioned-schemas
```

## Usage

```python

```

## License

[BSD 3-Clause License](LICENSE)
